import React, {useCallback} from "react";
import {useColumn} from "../Column";
import {useTable} from "../Smartable";
import {SortType} from "../Sort";

/**
 * Default column heading component.
 */
export function ColumnHeading()
{
	// Get current column data.
	const {key, column, sortState} = useColumn();

	// Get column sort state setter.
	const {setColumnSortState} = useTable();

	// Initialize handle click function.
	const handleClick = useCallback((event: React.MouseEvent) => {
		if (event.button == 0)
		{ // Normal click (usually left click).
			// Toggle sort type.
			setColumnSortState(key, sortState?.type == SortType.ASC ? SortType.DESC : SortType.ASC);
		}
		else if (event.button == 2 || event.button == 1)
		{ // Alt click (usually right or middle click).
			// Reset sort type.
			setColumnSortState(key, null);
		}
	}, [key, sortState, setColumnSortState]);

	// Disable context menu function.
	const disableContextMenu = useCallback((event: React.MouseEvent) => {
		event.preventDefault();
		return false;
	}, []);

	return (
		<th className={sortState?.type ?? undefined} data-sort-order={sortState?.order ?? undefined}
		    onMouseDown={handleClick} onContextMenu={disableContextMenu}>
			{column.title}

			{sortState?.order && <span className={"order"}>{sortState.order}</span>}
		</th>
	);
}
